pub enum DataRef<'a> {
Int(i64),
Float(f64),
String(String),
SharedString(&'a str),
SharedRichText(&'a RichText),
Bool(bool),
DateTime(ExcelDateTime),
DateTimeIso(String),
DurationIso(String),
Error(CellErrorType),
Empty,
}Expand description
An enum to represent all different data types that can appear as a value in a worksheet cell
Variants
Int(i64)
Signed integer
Float(f64)
Float
String(String)
String
Shared String
Shared Rich Text (reference to rich text in shared strings table)
Bool(bool)
Boolean
DateTime(ExcelDateTime)
Date or Time
DateTimeIso(String)
Date, Time or Date/Time in ISO 8601
DurationIso(String)
Duration in ISO 8601
Error(CellErrorType)
Error
Empty
Empty cell