XlsxError

Enum XlsxError 

pub enum XlsxError {
Show 29 variants Io(Error), Zip(ZipError), Vba(VbaError), Xml(Error), XmlAttr(AttrError), Parse(ParseError), ParseFloat(ParseFloatError), ParseInt(ParseIntError), XmlEof(&'static str), UnexpectedNode(&'static str), FileNotFound(String), RelationshipNotFound, Alphanumeric(u8), NumericColumn(u8), RangeWithoutColumnComponent, RangeWithoutRowComponent, ColumnNumberOverflow, RowNumberOverflow, DimensionCount(usize), CellTAttribute(String), Unexpected(&'static str), Unrecognized { typ: &'static str, val: String, }, CellError(String), Password, WorksheetNotFound(String), TableNotFound(String), NotAWorksheet(String), Encoding(EncodingError), PivotTableNotFound(String),
}
An enum for Xlsx specific errors.

Variants



Io(Error)

A wrapper for a variety of std::io::Error errors such as file permissions when reading an XLSX file. This can be caused by a non-existent file or parent directory or, commonly on Windows, if the file is already open in Excel.



Zip(ZipError)

A wrapper for a variety of zip::result::ZipError errors from zip::ZipWriter. These relate to errors arising from reading the XLSX file zip container.



Vba(VbaError)

A general error when reading a VBA project from an XLSX file.



Xml(Error)

A wrapper for a variety of quick_xml::Error XML parsing errors, but most commonly for missing data in the target file.



XmlAttr(AttrError)

A wrapper for a variety of quick_xml::events::attributes::AttrError errors related to attributes in XML elements.



Parse(ParseError)

A wrapper for a variety of std::string::ParseError errors when parsing strings.



ParseFloat(ParseFloatError)

A wrapper for a variety of std::num::ParseFloatError errors when parsing floats.



ParseInt(ParseIntError)

A wrapper for a variety of std::num::ParseIntError errors when parsing integers.



XmlEof(&'static str)

Unexpected end of XML file, usually when an end tag is missing.



UnexpectedNode(&'static str)

Unexpected node in XML.



FileNotFound(String)

XML file not found in XLSX container.



RelationshipNotFound

Relationship file not found in XLSX container.



Alphanumeric(u8)

Non alphanumeric character found when parsing A1 style range string.



NumericColumn(u8)

Error when parsing the column name in a A1 style range string.



RangeWithoutColumnComponent

Missing column name when parsing an A1 style range string.



RangeWithoutRowComponent

Missing row number when parsing an A1 style range string.



ColumnNumberOverflow

Column number exceeds maximum allowed columns.



RowNumberOverflow

Row number exceeds maximum allowed rows.



DimensionCount(usize)

Error when parsing dimensions of a worksheet.



CellTAttribute(String)

Unknown cell type (t) attribute.



Unexpected(&'static str)

Unexpected XML element or attribute error.



Unrecognized

Unrecognized worksheet type or state.

Fields

typ: &'static str

The data type.

val: String

The value found.



CellError(String)

Unrecognized cell error type.



Password

Workbook is password protected.



WorksheetNotFound(String)

Specified worksheet was not found.



TableNotFound(String)

Specified worksheet Table was not found.



NotAWorksheet(String)

The specified sheet is not a worksheet.



Encoding(EncodingError)

A wrapper for a variety of quick_xml::encoding::EncodingError encoding errors.



PivotTableNotFound(String)

Specified Pivot Table was not found on worksheet.