pub trait ReaderRef<RS>: Reader<RS>{
// Required method
fn worksheet_range_ref<'a>(
&'a mut self,
name: &str,
) -> Result<Range<DataRef<'a>>, Self::Error>;
// Provided method
fn worksheet_range_at_ref(
&mut self,
n: usize,
) -> Option<Result<Range<DataRef<'_>>, Self::Error>> { ... }
}Expand description
A trait to share spreadsheets reader functions across different FileTypes
Required Methods
Sourcefn worksheet_range_ref<'a>(
&'a mut self,
name: &str,
) -> Result<Range<DataRef<'a>>, Self::Error>
fn worksheet_range_ref<'a>( &'a mut self, name: &str, ) -> Result<Range<DataRef<'a>>, Self::Error>
Get worksheet range where shared string values are only borrowed.
This is implemented only for calamine::Xlsx and calamine::Xlsb, as Xls and Ods formats
do not support lazy iteration.
Provided Methods
Sourcefn worksheet_range_at_ref(
&mut self,
n: usize,
) -> Option<Result<Range<DataRef<'_>>, Self::Error>>
fn worksheet_range_at_ref( &mut self, n: usize, ) -> Option<Result<Range<DataRef<'_>>, Self::Error>>
Get the nth worksheet range where shared string values are only borrowed. Shortcut for getting the nth worksheet name, then the corresponding worksheet.
This is implemented only for calamine::Xlsx and calamine::Xlsb, as Xls and Ods formats
do not support lazy iteration.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.