VbaProject

Struct VbaProject 

pub struct VbaProject { /* private fields */ }
A struct for managing VBA reading

Implementations

Source

impl VbaProject

pub fn new<R: Read>(r: &mut R, len: usize) -> Result<VbaProject, VbaError>

Create a new VbaProject out of the vbaProject.bin ZipFile or xls file

Starts reading project metadata (header, directories, sectors and minisectors).

pub fn get_references(&self) -> &[Reference]

Gets the list of References

pub fn get_module_names(&self) -> Vec<&str>

Gets the list of Module names

pub fn get_module(&self, name: &str) -> Result<String, VbaError>

Reads module content and tries to convert to utf8

While it works most of the time, the modules are MBCS encoding and the conversion may fail. If this is the case you should revert to read_module_raw as there is no built in decoding provided in this crate

Examples
use calamine::{Reader, open_workbook, Xlsx};

let mut xl: Xlsx<_> = open_workbook(path).expect("Cannot find excel file");
if let Ok(Some(vba)) = xl.vba_project() {
    let modules = vba.get_module_names().into_iter()
                     .map(|s| s.to_string()).collect::<Vec<_>>();
    for m in modules {
        println!("Module {m}:");
        println!("{}", vba.get_module(&m)
                          .unwrap_or_else(|_| panic!("cannot read {m:?} module")));
    }
}
pub fn get_module_raw(&self, name: &str) -> Result<&[u8], VbaError>

Reads module content (MBCS encoded) and output it as-is (binary output)